==> customer-link-project-api-0.1.14-20230114.142634-1-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/SendMoneyReq.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

import cn.com.duiba.customer.link.project.api.remoteservice.app89420.dto.CommonReqDTO;

import java.util.List;

/**
 * @author lvgm
 * @date 2023/1/6
 */
public class SendMoneyReq extends CommonReqDTO {

    /**
     * 期次号
     * String(50)
     * YYYYMMDD
     * 不一定用日期，自己约定好，不要有特殊字符
     *
     */
    private String cycle;

    /**
     * 本次请求批次号 议按照顺序排
     * 每批批次号不同,第一次推送的记录在哪个批次号重推的时候批次号要相同
     */
    private String batchNumber;

    /**
     * 本次推送是否是重推数据
     */
    private Boolean isRepeat;

    /**
     * 本cycle期次下的总记录数
     */
    private Integer totalSum;

    /**
     * 需发红包的批量数据
     * 一次5000条推送
     */
    private List<SendMoneyRequestRow> requestRowList;

    public String getCycle() {
        return cycle;
    }

    public void setCycle(String cycle) {
        this.cycle = cycle;
    }

    public String getBatchNumber() {
        return batchNumber;
    }

    public void setBatchNumber(String batchNumber) {
        this.batchNumber = batchNumber;
    }

    public Boolean getRepeat() {
        return isRepeat;
    }

    public void setRepeat(Boolean repeat) {
        isRepeat = repeat;
    }

    public Integer getTotalSum() {
        return totalSum;
    }

    public void setTotalSum(Integer totalSum) {
        this.totalSum = totalSum;
    }

    public List<SendMoneyRequestRow> getRequestRowList() {
        return requestRowList;
    }

    public void setRequestRowList(List<SendMoneyRequestRow> requestRowList) {
        this.requestRowList = requestRowList;
    }
}

==> customer-link-project-api-1.1.25-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app89420/vo/SendMoneyReq.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app89420.vo;

import cn.com.duiba.customer.link.project.api.remoteservice.app89420.dto.CommonReqDTO;

import java.util.List;

/**
 * @author lvgm
 * @date 2023/1/6
 */
public class SendMoneyReq extends CommonReqDTO {

    /**
     * 期次号
     * String(50)
     * YYYYMMDD
     * 不一定用日期，自己约定好，不要有特殊字符
     *
     */
    private String cycle;

    /**
     * 开奖时间（yyyy-MM-dd HH:mm:ss）
     */
    private String drawDate;

    /**
     * 本次请求批次号 议按照顺序排
     * 每批批次号不同,第一次推送的记录在哪个批次号重推的时候批次号要相同
     */
    private String batchNumber;

    /**
     * 本次推送是否是重推数据（2025年3月25日之后不需要了）
     */
    private Boolean isRepeat;

    /**
     * 本cycle期次下的总记录数
     */
    private Integer totalSum;

    /**
     * 需发红包的批量数据
     * 一次推送最多2000条
     */
    private List<SendMoneyRequestRow> requestRowList;

    /**
     * 品牌（kww：口味王；hctx：和成天下）
     */
    private String brandCode;

    public String getCycle() {
        return cycle;
    }

    public void setCycle(String cycle) {
        this.cycle = cycle;
    }

    public String getDrawDate() {
        return drawDate;
    }

    public void setDrawDate(String drawDate) {
        this.drawDate = drawDate;
    }

    public String getBatchNumber() {
        return batchNumber;
    }

    public void setBatchNumber(String batchNumber) {
        this.batchNumber = batchNumber;
    }

    public Boolean getRepeat() {
        return isRepeat;
    }

    public void setRepeat(Boolean repeat) {
        isRepeat = repeat;
    }

    public Integer getTotalSum() {
        return totalSum;
    }

    public void setTotalSum(Integer totalSum) {
        this.totalSum = totalSum;
    }

    public List<SendMoneyRequestRow> getRequestRowList() {
        return requestRowList;
    }

    public void setRequestRowList(List<SendMoneyRequestRow> requestRowList) {
        this.requestRowList = requestRowList;
    }

    public String getBrandCode() {
        return brandCode;
    }

    public void setBrandCode(String brandCode) {
        this.brandCode = brandCode;
    }
}
